@@ -26,18 +26,8 @@ def get_class(func):
 
 class HANDLER:
     '''
-    # Internal use only
-    ## A global SLashCommand handler
-    This is done in order to give an ability to
-    decorate functions across multiple files
-    ```
-    from dislash import slash_commands
-
-    @slash_commands.command()
-    async def hello(interaction):
-        await interaction.reply('Hi')
-    ```
-    ### Note that you should init `SlashClient` to track `interaction_create` events
+    Internal use only
+    -----------------
     '''
     client = None
     commands = {}
@@ -348,7 +338,7 @@ class SlashClient:
                 print("SlashClient is ready")
         
         | All possible events:
-        | ``on_ready``, ``on_slash_command_error``
+        | ``on_ready``, ``on_slash_command``, ``on_slash_command_error``
         '''
         if not asyncio.iscoroutinefunction(func):
             raise TypeError(f'<{func.__qualname__}> must be a coroutine function')
